@@ -5,10 +5,10 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-06-20'; # DATE
 our $DIST = 'Acme-CPANModules-PickingRandomItemsFromList'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our $LIST = {
-    summary => 'Picking random items from a list',
+    summary => 'List of modules to pick random items from a list',
     description => <<'_',
 
 If you are picking random lines from a file, there's a separate CPANModules list
@@ -73,7 +73,7 @@ _
 };
 
 1;
-# ABSTRACT: Picking random items from a list
+# ABSTRACT: List of modules to pick random items from a list
 
 __END__
 
@@ -83,11 +83,11 @@ __END__
 
 =head1 NAME
 
-Acme::CPANModules::PickingRandomItemsFromList - Picking random items from a list
+Acme::CPANModules::PickingRandomItemsFromList - List of modules to pick random items from a list
 
 =head1 VERSION
 
-This document describes version 0.004 of Acme::CPANModules::PickingRandomItemsFromList (from Perl distribution Acme-CPANModules-PickingRandomItemsFromList), released on 2023-06-20.
+This document describes version 0.005 of Acme::CPANModules::PickingRandomItemsFromList (from Perl distribution Acme-CPANModules-PickingRandomItemsFromList), released on 2023-06-20.
 
 =head1 DESCRIPTION
 
